<?php

namespace App\Http\Controllers\Administrator;

use App\Models\User;
use App\Models\UserDetail;
use Illuminate\Http\Request;
use App\Models\CompanyContact;
use App\Http\Controllers\Controller;

class AdminController extends Controller
{
    public function index() {
        $users = User::with(['detail', 'contact'])->where('role', 0)->get()->all();
        return view('admin.index', [
            'users' => $users
        ]);
    }

    public function edit($id) {
        $user = User::with(['detail', 'contact'])->findOrFail($id);

        $bcategoryArray = [ 
            'Art and Animation' => '', 
            'Audio/Sound Design' => '', 
            'Game Development' => '', 
            'Publisher/Agency' => '', 
            'IP Licensing' => '', 
            'Advertisement' => '', 
            'Digital Media Marketing' => '', 
            'Event Management' => '', 
            'Game-related Hardware' => '', 
            'Game-related Software' => '', 
            'Game-related Platform' => '', 
            'Payment/Monetization' => '', 
            'Localization' => '', 
            'Venture Capital' => '', 
            'Crowdfunding Platform' => '', 
            'GameFi' => '', 
            'Indie Game Developer' => ''
        ];

        $pcategoryArray = [ 
            'PC game' => '', 
            'Online game' => '', 
            'Console game' => '', 
            'Mobile Apps' => '', 
            'Web game' => '', 
            'AR' => '', 
            'VR' => '', 
            'Blockchain game' => '', 
            'Other' => '', 
        ];

        $tcategoryArray = [ 
            'Art and Animation' => '', 
            'Audio/Sound Design' => '', 
            'Game Development' => '', 
            'Publisher/Agency' => '', 
            'IP Licensing' => '', 
            'Advertisement' => '', 
            'Digital Media Marketing' => '', 
            'Event Management' => '', 
            'Game-related Hardware' => '', 
            'Game-related Software' => '', 
            'Game-related Platform' => '', 
            'Payment/Monetization' => '', 
            'Localization' => '', 
            'Venture Capital' => '', 
            'Crowdfunding Platform' => '', 
            'GameFi' => '', 
            'Indie Game Developer' => ''
        ];

        $tmarketArray = [ 
            'Philippines' => '', 
            'Malaysia' => '', 
            'Singapore' => '', 
            'Southeast Asia' => '', 
            'Northeast Asia' => '', 
            'North America' => '', 
            'Middle East' => '', 
            'Europe' => '', 
            'Central and South America' => '', 
            'Other' => ''
        ];


        $bcategory = explode(',', $user->detail->business_category);
        $pcategory = explode(',', $user->detail->product_category);
        $tcategory = explode(',', $user->detail->target_category);
        $tmarket = explode(',', $user->detail->target_market);


        foreach($bcategoryArray as $key => $value) {
            foreach($bcategory as $category) {
                if($key == $category) {
                    $bcategoryArray[$key] = 'checked';
                }
            }
        }

        foreach($pcategoryArray as $key => $value) {
            foreach($pcategory as $category) {
                if($key == $category) {
                    $pcategoryArray[$key] = 'checked';
                }
            }
        }

        foreach($tcategoryArray as $key => $value) {
            foreach($tcategory as $category) {
                if($key == $category) {
                    $tcategoryArray[$key] = 'checked';
                }
            }
        }

        foreach($tmarketArray as $key => $value) {
            foreach($tmarket as $category) {
                if($key == $category) {
                    $tmarketArray[$key] = 'checked';
                }
            }
        }

        return view('admin.edit', [
            'user' => $user,
            'bcategoryArray' => $bcategoryArray,
            'pcategoryArray' => $pcategoryArray,
            'tcategoryArray' => $tcategoryArray,
            'tmarketArray' => $tmarketArray,
        ]);
    }


    public function update(Request $request, $id) {
        // $this-validate($request, [
        //     'country' => 'required',
        //     'product_category' => 'required',
        //     'business_category' => 'required',
        //     'target_market' => 'required',
        //     'target_category' => 'required',
        //     'whatsapp' => 'required_without_all:line,viber,skype,wechat',
        //     'line' => 'required_without_all:whatsapp,viber,skype,wechat',
        //     'viber' => 'required_without_all:line,whatsapp,skype,wechat',
        //     'skype' => 'required_without_all:line,viber,whatsapp,wechat',
        //     'wechat' => 'required_without_all:line,viber,skype,whatsapp'
        // ]);

        $user = User::with(['detail', 'contact'])->findOrFail($id);
        $detail = UserDetail::where('user_id', $user->id)->get()->first();
        $contact = CompanyContact::where('user_id', $user->id)->get()->first();
        // dd($request);
        $tcategory = implode(',', $request->target_category);
        $bcategory = implode(',', $request->business_category);
        $pcategory = implode(',', $request->product_category);
        $tmarket = implode(',', $request->target_market);

        
        $detail->contact = $request->contact;
        $detail->contact_position = $request->position;
        $detail->number = $request->number;
        $detail->business_category = $bcategory;
        $detail->country = $request->country;
        $detail->product_category = $pcategory;
        $detail->target_market = $tmarket;
        $detail->target_category = $tcategory;
        $contact->whatsapp = $request->whatsapp;
        $contact->viber = $request->viber;
        $contact->wechat = $request->wechat;
        $contact->line = $request->line;
        $contact->skype = $request->skype;
        $detail->company_website = $request->company_website;
        $detail->community_website = $request->community_website;
        $detail->company_description = $request->company_description;

        $logo = $request->file('company_logo');

        if($logo) {
            $filename = $logo->getClientOriginalName();
            $user->detail->company_logo = $filename;
            $logo->move(public_path('assets/img/company'), $filename);
        }

        $user->save();
        $contact->save();
        $detail->save();
        return redirect(route('admin.user.edit', $user->id))->with('success-edit', 'You have successfully edited user information.');
    }

    public function pending() {
        $users = User::with(['detail', 'contact'])->where('status', 0)->where('role', 0)->get()->all();
        return view('admin.pending_user', [
            'users' => $users
        ]);
    }

    public function pendingView($id) {
        $user = User::with(['detail', 'contact'])->findOrFail($id);

        return view('admin.pending_view', [
            'user' => $user
        ]);
    }

    public function acceptUser($id) {
        $user = User::findOrFail($id);
        $user->status = 1;
        $user->save();

        Mail::to($user->email)->send(new UserAccept);

        if (Mail::failures()) {
            return response()->Fail('Sorry! Please try again latter');
        } else {
            return back()->with('success-accept', 'User Registration successfully approved!');
        }
    }

    public function rejectUser($id) {
        $user = User::findOrFail($id);
        $user->status = 0;
        $user->save();

        Mail::to($user->email)->send(new UserReject);

        if (Mail::failures()) {
            return response()->Fail('Sorry! Please try again latter');
        } else {
            return back()->with('success-reject', 'User Registration successfully rejected!');
        }
    }
}
