<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\MailController;
use App\Http\Controllers\Administrator\AdminController;
use Illuminate\Foundation\Auth\EmailVerificationRequest;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', [HomeController::class, 'login'])->name('login.show');
Route::get('/home', [HomeController::class, 'login'])->name('user.home');
Route::get('/register_user', [HomeController::class, 'register'])->name('register.shows');
Route::post('/register_user', [HomeController::class, 'registerUser'])->name('user.register');
Route::get('/register_user/email-succes/{email}', [MailController::class, 'successRegister'])->name('send.register.email');

Route::get('/email/verify', function () {
    return view('auth.verify-email');
})->middleware('auth')->name('verification.notice');

Route::get('/email/verify/{id}/{hash}', function (EmailVerificationRequest $request) {
    $request->fulfill();
 
    return redirect('/home');
})->middleware(['auth', 'signed'])->name('verification.verify');

Route::post('/email/verification-notification', function (Request $request) {
    $request->user()->sendEmailVerificationNotification();
 
    return back()->with('message', 'Verification link sent!');
})->middleware(['auth', 'throttle:6,1'])->name('verification.send');

Auth::routes();

// Route User
Route::middleware(['auth','user-role:user'])->group(function()
{
    Route::get("/biz-matching",[HomeController::class, 'index'])->name("user.dashboard");
    Route::get("/networking_list", [HomeController::class, 'network'])->name("user.network");
    Route::get("/networking_list/source", [HomeController::class, 'networkSource'])->name("user.network_list.source");
    Route::get("/meeting_list", [HomeController::class, 'meetingRequest'])->name("user.meeting.requests");
    Route::get("/meeting_schedule", [HomeController::class, 'meetingSchedule'])->name("user.meeting.schedule");
    Route::put("/meeting_schedule/closed/{id}/{tid}/{did}", [HomeController::class, 'meetingClose'])->name("user.meeting.close");
    Route::put("/meeting_schedule/open/{id}/{tid}/{did}", [HomeController::class, 'meetingOpen'])->name("user.meeting.open");
    Route::get("/meeting_book/{id}", [HomeController::class, 'meetingBook'])->name("user.book.meeting");
    Route::post("/meeting/meeting-request", [HomeController::class, 'setMeeting'])->name("user.meeting.set");
    Route::post("/meeting/meeting-request/accept/{mid}", [HomeController::class, 'acceptMeeting'])->name("user.meeting.accept");
    Route::post("/meeting/meeting-request/reject/{mid}", [HomeController::class, 'rejectMeeting'])->name("user.meeting.reject");


    Route::get("networking_list/card_exchange/{id}", [HomeController::class, 'ajaxCardExchange'])->name("user.card.exchange.modal");
    Route::post("networking_list/card_exchange", [HomeController::class, 'cardRequest'])->name("user.card.exchange.request");

    Route::get("/card_exchange", [HomeController::class, 'cardExchange'])->name("user.card.exchange");
    Route::post("/card_exchange/accept/{id}", [HomeController::class, 'acceptCard'])->name("user.card.exchange.accept");
    Route::post("/card_exchange/reject/{id}", [HomeController::class, 'rejectCard'])->name("user.card.exchange.reject");
    Route::get("/card/exchange/content/ajax/{id}", [HomeController::class, 'ajaxCardShow'])->name("user.card.exchange.show");

    Route::get("/contact_info", [HomeController::class, 'contact'])->name('user.contact.info');
    Route::get("/contact_info/edit", [HomeController::class, 'contactEdit'])->name('user.contact.edit');
    Route::put("/contact_info/edit/{id}", [HomeController::class, 'contactEditStore'])->name('user.contact.edit.store');
});
// Route Editor
Route::middleware(['auth','user-role:admin'])->group(function()
{
    Route::get("/administrator/users",[AdminController::class, 'index'])->name("admin.dashboard");
    Route::get("/administrator/user/edit/{id}", [AdminController::class, 'edit'])->name('admin.user.edit');
    Route::put("/administrator/user/edit/{id}", [AdminController::class, 'update'])->name('admin.edit.store');
    Route::get("/administrator/user/review", [AdminController::class, 'pending'])->name('admin.pending.review');
    Route::get("/administrator/user/review/view/{id}", [AdminController::class, 'pendingView'])->name('user.pending.view');
    Route::post("/administrator/user/review/accept/{id}", [AdminController::class, 'acceptUser'])->name('admin.user.accept');
    Route::post("/administrator/user/review/reject/{id}", [AdminController::class, 'rejectUser'])->name('admin.user.reject');
});
